@@ -2,7 +2,7 @@ package Spreadsheet::XLSX::Reader::LibXML::Cell;
 BEGIN {
   $Spreadsheet::XLSX::Reader::LibXML::Cell::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv('v0.10.2');
+use version; our $VERSION = qv('v0.10.4');
 
 use 5.010;
 use Moose;
@@ -216,7 +216,7 @@ Spreadsheet::XLSX::Reader::LibXML::Cell - XLSX Cell data and formatting source
 
 =head1 SYNOPSIS
 
-See the SYNOPSIS in L<Spreadsheet::XLSX::Reader::LibXML> (The Workbook level class)
+See the SYNOPSIS in the L<Workbook class|Spreadsheet::XLSX::Reader::LibXML/SYNOPSIS>
     
 =head1 DESCRIPTION
 
@@ -848,23 +848,13 @@ it and/or modify it under the same terms as Perl itself.
 The full text of the license can be found in the
 LICENSE file included with this module.
 
-This software is copyrighted (c) 2014 by Jed Lund
+This software is copyrighted (c) 2014 by Jed 
 
 =head1 DEPENDENCIES
 
 =over
 
-B<5.010> - (L<perl>)
-
-L<version>
-
-L<Moose>
-
-L<MooseX::StrictConstructor>
-
-L<MooseX::HasDefaults::RO>
-
-L<Types::Standard>
+L<Spreadsheet::XLSX::Reader::LibXML>
 
 =back
 
@@ -872,14 +862,20 @@ L<Types::Standard>
 
 =over
 
-L<Spreadsheet::XLSX>
+L<Spreadsheet::ParseExcel> - Excel 2003 and earlier
 
-L<Spreadsheet::ParseXLSX>
+L<Spreadsheet::XLSX> - 2007+
 
-L<Spreadsheet::ParseExcel::Cell>
+L<Spreadsheet::ParseXLSX> - 2007+
 
 L<Log::Shiras|https://github.com/jandrew/Log-Shiras>
 
+=over
+
+All lines in this package that use Log::Shiras are commented out
+
+=back
+
 =back
 
 =cut
